@@ -32,12 +32,16 @@ use Pony::Object qw/Human::Base/;
     sub avgIn : Public
         {
             my $this = shift;
+            
+            return 0 if $this->inCount == 0;
             return sprintf( '%.2f', $this->in / $this->inCount );
         }
 
     sub avgOut : Public
         {
             my $this = shift;
+            
+            return 0 if $this->outCount == 0;
             return sprintf( '%.2f', $this->out / $this->outCount );
         }
     
